#include "metals.inc"

#declare SMOOTH=1.2       /* Surface smoothness. A value of 1.001 gives
			     simple spheres, higher values increase the
			     blending of the atoms. */

#declare VDW_FACTOR=1;    /* A value of 1 gives the actual VDW surface.
			     Decrease for a smaller surface. */

#declare ATOM_SCALE=VDW_FACTOR*SMOOTH

#declare THRESH=1-(1/(SMOOTH*SMOOTH))

#declare THRESH=THRESH * THRESH

#declare ATOM_FINISH=finish{
                       diffuse 0.5
                       specular 0.6
                       roughness 0.03
                       ambient 0.2
                     }

#declare ATOM_TRANS=rgbft <0, 0, 0, 0, 0>

/* The ELECTROSTATIC_MAP_TEXTURE texture is used when colouring by 
   electrostatics. Note that it will not work properly for charges 
   outside the range [-1..1]. */

#declare ELECTROSTATIC_MAP_TEXTURE=pigment {
   marble
   color_map{
     [0 color Red]
     [0.5 color Green]
     [1 color Blue]
   }
   rotate 90*y
   translate -0.5*z
   scale 2000
}

// Atom sizes are from the MM2 force field where defined, otherwise from 
// the AMBER force field.


#declare ATOM_1_SIZE = 1.94     // C1
#declare ATOM_2_SIZE = 1.94     // C2
#declare ATOM_3_SIZE = 1.90     // C3
#declare ATOM_4_SIZE = 1.85     // CH united atom
#declare ATOM_5_SIZE = 1.925    // CH2 united atom
#declare ATOM_6_SIZE = 2.00     // CH3 united atom
#declare ATOM_7_SIZE = 1.85     // CH sp2 united atom
#declare ATOM_8_SIZE = 1.85     // CH2 sp2 united atom
#declare ATOM_9_SIZE = 1.80     // CH sp united atom
#declare ATOM_10_SIZE = 1.90     // unknown
#declare ATOM_11_SIZE = 1.94     // C+ 
#declare ATOM_12_SIZE = 1.90     // C radical 
#declare ATOM_13_SIZE = 1.90     // unknown 
#declare ATOM_14_SIZE = 1.90     // 'Any' C 
#declare ATOM_15_SIZE = 1.74    // O2
#declare ATOM_16_SIZE = 1.74    // O3
#declare ATOM_17_SIZE = 1.74    // OH united atom 
#declare ATOM_18_SIZE = 1.74    // O-
#declare ATOM_19_SIZE = 1.74    // OW (united atom water)
#declare ATOM_20_SIZE = 1.74    // OP (oxonium sp2)
#declare ATOM_21_SIZE = 1.74    // OQ (oxonium sp3)
#declare ATOM_22_SIZE = 1.74    // unknown
#declare ATOM_23_SIZE = 1.74    // O0 ('Any' O)
#declare ATOM_24_SIZE = 1.82    // N1
#declare ATOM_25_SIZE = 1.82    // N2
#declare ATOM_26_SIZE = 1.82    // N3
#declare ATOM_27_SIZE = 1.82    // NH sp3 united atom
#declare ATOM_28_SIZE = 1.82    // NH2 sp3 united atom
#declare ATOM_29_SIZE = 1.82    // NH sp2 united atom
#declare ATOM_30_SIZE = 1.82    // NH2 sp2 united atom
#declare ATOM_31_SIZE = 1.82    // N+ sp2
#declare ATOM_32_SIZE = 1.82    // N+ sp3
#declare ATOM_33_SIZE = 1.82    // NH+ sp3 united atom
#declare ATOM_34_SIZE = 1.82    // NH2+ sp3 united atom
#declare ATOM_35_SIZE = 1.82    // NH3+ sp3 united atom
#declare ATOM_36_SIZE = 1.82    // NH+ sp2 united atom
#declare ATOM_37_SIZE = 1.82    // NH2+ sp2 united atom
#declare ATOM_38_SIZE = 1.74    // unknown
#declare ATOM_39_SIZE = 1.74    // unknown
#declare ATOM_40_SIZE = 1.82    // N0 'Any' N
#declare ATOM_41_SIZE = 1.50    // H
#declare ATOM_42_SIZE = 1.20    // H(-O)
#declare ATOM_43_SIZE = 1.32    // H(-N)
#declare ATOM_44_SIZE = 1.20    // H+
#declare ATOM_45_SIZE = 1.70    // H-
#declare ATOM_46_SIZE = 1.74    // unknown
#declare ATOM_47_SIZE = 1.74    // unknown
#declare ATOM_48_SIZE = 1.50    // H0 'Any' H
#declare ATOM_49_SIZE = 2.11    // S1
#declare ATOM_50_SIZE = 2.11    // SH united atom
#declare ATOM_51_SIZE = 2.11    // Thiolate anion
#declare ATOM_52_SIZE = 2.11    // S0
#declare ATOM_53_SIZE = 2.18    // P0
#declare ATOM_54_SIZE = 1.98    // B sp2
#declare ATOM_55_SIZE = 1.98    // B sp3
#declare ATOM_56_SIZE = 1.65    // F
#declare ATOM_57_SIZE = 2.03    // Cl
#declare ATOM_58_SIZE = 2.18    // Br
#declare ATOM_59_SIZE = 2.32    // I
#declare ATOM_60_SIZE = 2.25    // Si
#declare ATOM_61_SIZE = 0.00    // Du
#declare ATOM_62_SIZE = 1.50    // Z0 (Lithium)
#declare ATOM_63_SIZE = 1.20    // Lp

/* The following textures are used when colouring by type... */

#declare ATOM_1_TEXTURE = texture {
                            pigment { color Gray70 + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_2_TEXTURE = texture {
                            pigment { color Gray70 + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_3_TEXTURE = texture {
                            pigment { color Gray70 + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_4_TEXTURE = texture {
                            pigment { color Gray70 + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_5_TEXTURE = texture {
                            pigment { color Gray70 + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_6_TEXTURE = texture {
                            pigment { color Gray70 + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_7_TEXTURE = texture {
                            pigment { color Gray70 + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_8_TEXTURE = texture {
                            pigment { color Gray70 + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_9_TEXTURE = texture {
                            pigment { color Gray70 + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_10_TEXTURE = texture {
                            pigment { color Gray70 + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_11_TEXTURE = texture {
                            pigment { color Gray70 + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_12_TEXTURE = texture {
                            pigment { color Gray70 + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_13_TEXTURE = texture {
                            pigment { color Gray70 + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_14_TEXTURE = texture {
                            pigment { color Gray70 + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_15_TEXTURE = texture {
                            pigment { color Red + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_16_TEXTURE = texture {
                            pigment { color Red + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_17_TEXTURE = texture {
                            pigment { color Red + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_18_TEXTURE = texture {
                            pigment { color Red + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_19_TEXTURE = texture {
                            pigment { color Red + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_20_TEXTURE = texture {
                            pigment { color Red + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_21_TEXTURE = texture {
                            pigment { color Red + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_22_TEXTURE = texture {
                            pigment { color Gray70 + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_23_TEXTURE = texture {
                            pigment { color Red + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_24_TEXTURE = texture {
                            pigment { color Blue + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_25_TEXTURE = texture {
                            pigment { color Blue + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_26_TEXTURE = texture {
                            pigment { color Blue + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_27_TEXTURE = texture {
                            pigment { color Blue + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_28_TEXTURE = texture {
                            pigment { color Blue + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_29_TEXTURE = texture {
                            pigment { color Blue + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_30_TEXTURE = texture {
                            pigment { color Blue + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_31_TEXTURE = texture {
                            pigment { color Blue + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_32_TEXTURE = texture {
                            pigment { color Blue + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_33_TEXTURE = texture {
                            pigment { color Blue + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_34_TEXTURE = texture {
                            pigment { color Blue + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_35_TEXTURE = texture {
                            pigment { color Blue + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_36_TEXTURE = texture {
                            pigment { color Blue + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_37_TEXTURE = texture {
                            pigment { color Blue + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_38_TEXTURE = texture {
                            pigment { color Gray70 + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_39_TEXTURE = texture {
                            pigment { color Gray70 + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_40_TEXTURE = texture {
                            pigment { color Blue + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_41_TEXTURE = texture {
                            pigment { color White + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_42_TEXTURE = texture {
                            pigment { color White + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_43_TEXTURE = texture {
                            pigment { color White + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_44_TEXTURE = texture {
                            pigment { color White + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_45_TEXTURE = texture {
                            pigment { color White + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_46_TEXTURE = texture {
                            pigment { color Gray70 + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_47_TEXTURE = texture {
                            pigment { color Gray70 + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_48_TEXTURE = texture {
                            pigment { color White + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_49_TEXTURE = texture {
                            pigment { color Yellow + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_50_TEXTURE = texture {
                            pigment { color Yellow + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_51_TEXTURE = texture {
                            pigment { color Yellow + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_52_TEXTURE = texture {
                            pigment { color Yellow + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_53_TEXTURE = texture {
                            pigment { color Aquamarine + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_54_TEXTURE = texture {
                            pigment { color Cyan + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_55_TEXTURE = texture {
                            pigment { color Cyan + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_56_TEXTURE = texture {
                            pigment { color Green + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_57_TEXTURE = texture {
                            pigment { color Green + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_58_TEXTURE = texture {
                            pigment { color Brown + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_59_TEXTURE = texture {
                            pigment { color Med_Purple + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_60_TEXTURE = texture {
                            T_Silver_2B
			  }

#declare ATOM_61_TEXTURE = texture {
                            pigment { color Clear + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

#declare ATOM_62_TEXTURE = texture {
                            T_Chrome_2C
			  }

#declare ATOM_63_TEXTURE = texture {
                            pigment { color Red + ATOM_TRANS}
			    finish { ATOM_FINISH }
			  }

