/* MMOD2POV version 1.1.1 16/5/96 */
/* Copyright (C) 1996 Mark Mackey */

#include <stdlib.h>
#include <stdio.h>

#define MAXMOLS 1000
#define MAXLENGTH 200

struct atomstruct {
  int type;
  float x,y,z;
  float charge;
};

struct molstruct {
  struct atomstruct avg,min,max;
};

void WriteHeader(FILE *fp, float width)
/* Writes the header, camera etc. information to a file */
{
  fprintf(fp,"// This file was produced using MMOD2POV v1.1.1\n");
  fprintf(fp,"// MMOD2POV is Copyright (C) 1996 M. Mackey.\n\n");
  fprintf(fp,"#version 3.0\n");
  fprintf(fp,"global_settings { assumed_gamma 2.2 }\n\n");
  fprintf(fp,"#declare CAMERA_DISTANCE = %f\n\n",width*2.7);
  fprintf(fp,"#include \"colors.inc\"\n");
  fprintf(fp,"#include \"finish.inc\"\n");
  fprintf(fp,"#include \"camera.inc\"\n");
  fprintf(fp,"#include \"lights.inc\"\n");
  fprintf(fp,"#include \"backgr.inc\"\n\n");
}

#ifdef READSLINE
char *Readline(FILE *fp)
/* Reads in a line of text */
{
  int i=0;
  char *s=malloc(MAXLENGTH*sizeof(char));
  while (s[i++]=fgetc(fp)!='\n')
}
#endif

void ScanMModFile(FILE *infp, int num_atoms, struct atomstruct *atom, struct molstruct *mol)
/* Reads in all atom positions and returns the average */
{
  int c;
  
  printf("Scanning file...\n");
  
  for (;num_atoms>0;num_atoms--) {
#ifdef ELECTROSTATICS
    fscanf(infp,"\n %i %*d%*d%*d%*d%*d%*d%*d%*d%*d%*d%*d%*d %f %f %f %*s %*s %f",&atom->type,&atom->x,&atom->y,&atom->z,&atom->charge); 
#else
    fscanf(infp,"\n %i %*d%*d%*d%*d%*d%*d%*d%*d%*d%*d%*d%*d %f %f %f",&atom->type,&atom->x,&atom->y,&atom->z); 
#endif
    mol->avg.x+=atom->x;
    mol->avg.y+=atom->y;
    mol->avg.z+=atom->z;
    if (atom->x<mol->min.x) mol->min.x=atom->x;
    if (atom->y<mol->min.y) mol->min.y=atom->y;
    if (atom->z<mol->min.z) mol->min.z=atom->z;
    if (atom->x>mol->max.x) mol->max.x=atom->x;
    if (atom->y>mol->max.y) mol->max.y=atom->y;
    if (atom->z>mol->max.z) mol->max.z=atom->z;

#ifdef DEBUG
    printf(" x: %f y: %f z: %f charge: %f\n",atom->x, atom->y, atom->z, atom->charge);
    printf("%i Average: x: %f y: %f z: %f \n",num_atoms,mol->avg.x, mol->avg.y, mol->avg.z);
    printf("  %p \n\n",atom);
#endif

    atom++;
    while (((c=fgetc(infp))!='\n') && (c!=EOF)) {
      ;
    }
  }
}
  
void WritePositions(FILE *outfp, int num_atoms, struct atomstruct *atoms, struct atomstruct *avg, int texture_by_type)
{
  for (;num_atoms>0;num_atoms--) {
    fprintf(outfp,"  sphere { <%f, %f, %f>, ATOM_%i_SIZE*ATOM_SCALE strength 1.0\n",atoms->x-avg->x,atoms->y-avg->y,atoms->z-avg->z,atoms->type);
    if (texture_by_type) {
      fprintf(outfp,"    texture{ ATOM_%i_TEXTURE }\n",atoms->type);
    } else {
      fprintf(outfp,"    texture{ ELECTROSTATIC_MAP_TEXTURE translate %f*z }\n",atoms->charge*1000);
    }
    atoms++;
    fprintf(outfp,"  }\n");
  }
  fprintf(outfp,"}\n\n");
}


void WriteData(FILE *infp, FILE *outfp, int texture_by_type)
/* Writes the blob objects */
{
  int i,c;
  int num_atoms[MAXMOLS];
  int total_atoms=0;
  struct atomstruct *atoms[MAXMOLS];
  struct molstruct mol;
  char name[100][MAXMOLS];
  int mol_num=0;
  float width;

  mol.avg.x=0;
  mol.avg.y=0;
  mol.avg.z=0;
  mol.min.x=100000;
  mol.min.y=100000;
  mol.min.z=100000;
  mol.max.x=-100000;
  mol.max.y=-100000;
  mol.max.z=-100000;

  while (fscanf(infp," %i%s",&num_atoms[mol_num],name[mol_num])>0) {
    
    atoms[mol_num]=malloc(num_atoms[mol_num]*sizeof(struct atomstruct));
    
    while (((c=fgetc(infp))!='\n') && (c!=EOF)) {
      ;
    }
    printf("\nNumber of atoms: %4i    Molecule name: %s\n",num_atoms[mol_num],name[mol_num]);
    total_atoms+=num_atoms[mol_num];
    ScanMModFile(infp,num_atoms[mol_num],atoms[mol_num],&mol);
    mol_num++;
  }

  mol.avg.x=mol.avg.x/total_atoms;
  mol.avg.y=mol.avg.y/total_atoms;
  mol.avg.z=mol.avg.z/total_atoms;
  
  mol.max.x-=mol.min.x;
  mol.max.y-=mol.min.y;
  mol.max.z-=mol.min.z;
  
  width=(mol.max.x>mol.max.y)?mol.max.x:mol.max.y;

  WriteHeader(outfp,width);
  
  for (i=0;i<mol_num;i++) {
    fprintf(outfp,"// Molecule: %s\n\n",name[i]);
    fprintf(outfp,"#include \"atoms.inc\"\n\n");
    fprintf(outfp,"blob {\n");
    fprintf(outfp,"  threshold THRESH\n\n");
    printf("num_atoms: %i \n",num_atoms[i]);
    WritePositions(outfp,num_atoms[i],atoms[i],&mol.avg,texture_by_type);
    free(atoms[i]);
  }
}
  

int main(int argc,char *argv[])
{
  FILE *infp;
  FILE *outfp;
  int texture_by_type=1;
  int i;

  if (argc<3) {
    printf("\nMMOD2POV (C) 1996 M. Mackey. Version 1.1.1\n");
#ifdef ELECTROSTATICS
    printf("Syntax is %s [-e] <macromodel file> <output file>\n",argv[0]);
    printf("The -e option textures the molecule by electrostatics.\n\n");
#else
    printf("Syntax is %s <macromodel file> <output file>\n\n",argv[0]);
#endif
    exit(1);
  }
  i=1;
#ifdef ELECTROSTATICS
  if ((argv[i][0]=='-') && (argv[i][1]=='e')) {
    texture_by_type=0;
    printf("Texturing by electrostatics...");
    i++;
  }
#endif
  if ((infp=fopen(argv[i],"r"))==NULL) {
    printf("File %s not found.\n\n",argv[i]);
    exit(2);
  }
  if ((outfp=fopen(argv[i+1],"w"))==NULL) {
    printf("Unable to open file %s for output.\n\n",argv[i+1]);
    exit(3);
  }
  WriteData(infp,outfp,texture_by_type);
  printf("\nConversion complete.\n\n");
  fclose(infp);
  fclose(outfp);
}
  
